@@ -1,15 +1,15 @@
 import os
 
 # Location of the shared volume between sidecar and the processing step
-DATA_VOLUME_PATH = os.getenv("DATA_VOLUME_PATH")
+DATA_VOLUME_PATH = os.getenv("DATA_VOLUME_PATH", "")
 
 # Socket file paths for both what comes in and goes out
-FRAGMENTER_INPUT = ("" if DATA_VOLUME_PATH == None else DATA_VOLUME_PATH) + "/" + os.getenv("FRAGMENTER_INPUT", default="")
-FRAGMENTER_OUTPUT = ("" if DATA_VOLUME_PATH == None else DATA_VOLUME_PATH) + "/" + os.getenv("FRAGMENTER_OUTPUT", default="")
+FRAGMENTER_INPUT = DATA_VOLUME_PATH + "/" + os.getenv("FRAGMENTER_INPUT", default="")
+FRAGMENTER_OUTPUT = DATA_VOLUME_PATH + "/" + os.getenv("FRAGMENTER_OUTPUT", default="")
 
 # Socket file paths for both what comes in and goes out 
-TRANSFORMATION_STEP_INPUT = ("" if DATA_VOLUME_PATH == None else DATA_VOLUME_PATH) + "/" + os.getenv("TRANSFORMATION_STEP_INPUT", default="")
-TRANSFORMATION_STEP_OUTPUT = ("" if DATA_VOLUME_PATH == None else DATA_VOLUME_PATH) + "/" + os.getenv("TRANSFORMATION_STEP_OUTPUT", default="")
+TRANSFORMATION_STEP_INPUT = DATA_VOLUME_PATH + "/" + os.getenv("TRANSFORMATION_STEP_INPUT", default="")
+TRANSFORMATION_STEP_OUTPUT = DATA_VOLUME_PATH + "/" + os.getenv("TRANSFORMATION_STEP_OUTPUT", default="")
 
 # Size encoding of message with a default value of 4
 ENC_MSG_SIZE_LENGTH = os.getenv("ENC_MSG_SIZE_LENGTH", default=4)
@@ -18,11 +18,11 @@ EXAMPLE_SOCKET_INPUT = "./pyterum_example_sockets/example_in.sock"
 EXAMPLE_SOCKET_OUTPUT = "./pyterum_example_sockets/example_out.sock"
 
 def verify_fragmenter_envs():
-    assert DATA_VOLUME_PATH != None
+    assert DATA_VOLUME_PATH != ""
     assert FRAGMENTER_INPUT.endswith(".sock")
     assert FRAGMENTER_OUTPUT.endswith(".sock")
 
 def verify_transformation_step_envs():    
-    assert DATA_VOLUME_PATH != None
+    assert DATA_VOLUME_PATH != ""
     assert TRANSFORMATION_STEP_INPUT.endswith(".sock")
     assert TRANSFORMATION_STEP_OUTPUT.endswith(".sock")
